@@ -72,6 +72,9 @@ static char *env_debugfd = "NOCACHE_DEBUGFD";
 int debugfd = -1;
 FILE *debugfp;
 
+static char *env_flushall = "NOCACHE_FLUSHALL";
+static char flushall;
+
 #define DEBUG(...) \
     do { \
         if(debugfp != NULL) { \
@@ -88,7 +91,11 @@ static void init(void)
 
     getrlimit(RLIMIT_NOFILE, &rlim);
     max_fds = rlim.rlim_max;
+
     init_mutexes();
+    /* make sure to re-initialize mutex if forked */
+    pthread_atfork(NULL, NULL, init_mutexes);
+
     fds = malloc(max_fds * sizeof(*fds));
     assert(fds != NULL);
 
@@ -115,6 +122,11 @@ static void init(void)
     if(nr_fadvise <= 0)
         nr_fadvise = 1;
 
+    if((s = getenv(env_flushall)) != NULL)
+        flushall = atoi(s);
+    if(flushall <= 0)
+        flushall = 0;
+
     PAGESIZE = getpagesize();
     pthread_mutex_lock(&fds_iter_lock);
     for(i = 0; i < max_fds; i++) {
@@ -138,8 +150,6 @@ static void init_mutexes(void)
         pthread_mutex_init(&fds_lock[i], NULL);
     }
     pthread_mutex_unlock(&fds_iter_lock);
-    /* make sure to re-initialize mutex if forked */
-    pthread_atfork(NULL, NULL, init_mutexes);
 }
 
 static void init_debugging(void)
@@ -411,6 +421,9 @@ static void store_pageinfo(int fd)
     fadv_noreuse(fd, 0, 0);
 
     fds[fd].fd = fd;
+    if(flushall)
+        goto out;
+
     if(!fd_get_pageinfo(fd, &fds[fd])) {
         fds[fd].fd = -1;
         goto out;
@@ -452,6 +465,13 @@ static void free_unclaimed_pages(int fd)
 
     sync_if_writable(fd);
 
+    if(flushall) {
+        DEBUG("fadv_dontneed(fd=%d, from=0, len=0 [till end])\n", fd);
+        fadv_dontneed(fd, 0, 0, nr_fadvise);
+        fds[fd].fd = -1;
+        goto out;
+    }
+
     if(fstat(fd, &st) == -1)
         goto out;
 
